three_js library

Classes

AmbientLight
This light globally illuminates all objects in the scene equally.
AmbientLightProbe
Angle3DRenderTarget
AngleArrayRenderTarget
AngleRenderer
AngleRendererParameters
AnimationAction
AnimationActions schedule the performance of the animations which are stored in AnimationClips.
AnimationBinding
AnimationClip
An AnimationClip is a reusable set of keyframe tracks which represent an animation.
AnimationMixer
The AnimationMixer is a player for animations on a particular object in the scene. When multiple objects in the scene are animated independently, one AnimationMixer may be used for each object.
AnimationObject
This is almost identical to an Group. Its purpose is to make working with animatins of objects syntactically clearer.
AnimationObjectGroup
A group of objects that receives a shared animation state.
AnimationUtils
An object with various functions to assist with animations, used internally.
ArcCurve
Alias for EllipseCurve.
ArrayCamera
name can be used in order to efficiently render a scene with a predefined set of cameras. This is an important performance aspect for rendering VR scenes.
Audio
This utility class holds static references to some global audio objects.
BaseBufferAttribute<TData extends TypedDataList>
BaseRenderTarget
BatchedMesh
Blob
Fake Blob for fit web code when in App & Desktop
Bone
A bone which is part of a Skeleton. The skeleton in turn is used by the SkinnedMesh. Bones are almost identical to a blank Object3D.
BooleanKeyframeTrack
A Track of Boolean keyframe values.
BoundingBox
Represents an axis-aligned bounding box (AABB) in 3D space.
BoundingSphere
A sphere defined by a center and radius.
Bounds
BoxGeometry
name is a geometry class for a rectangular cuboid with a given width, height, and depth. On creation, the cuboid is centred on the origin, with each edge parallel to one of the axes.
BoxLineGeometry
BufferAttribute<TData extends TypedDataList>
This class stores data for an attribute (such as vertex positions, face indices, normals, colors, UVs, and any custom attributes ) associated with a BufferGeometry, which allows for more efficient passing of data to the GPU. See that page for details and a usage example. When working with vector-like data, the .fromBufferAttribute( attribute, index ) helper methods on Vector2, Vector3, Vector4, and Color classes may be helpful.
BufferGeometry
A representation of mesh, line, or point geometry. Includes vertex positions, face indices, normals, colors, UVs, and custom attributes within buffers, reducing the cost of passing all this data to the GPU.
BufferGeometryParameters
BVHLoader
Loader loads FBX file and generates Group representing FBX scene. Requires FBX file to be >= 7.0 and in ASCII or >= 6400 in Binary format Versions lower than this may load but will probably have errors
BVHObject
Cache
A simple caching system, used internally by FileLoader.
Camera
Abstract base class for cameras. This class should always be inherited when you build a new camera.
CameraView
CanvasTexture
Creates a texture from a canvas element.
Capabilities
CapsuleGeometry
CatmullRomCurve3
Create a smooth 3d spline curve from a series of points using the Catmull-Rom algorithm.
Chunk
CinquefoilKnot
CircleGeometry
CircleGeometry is a simple shape of Euclidean geometry. It is constructed from a number of triangular segments that are oriented around a central point and extend as far out as a given radius. It is built counter-clockwise from a start angle and a given central angle. It can also be used to create regular polygons, where the number of segments determines the number of sides.
Clock
Object for keeping track of time. This uses DateTime.now().millisecondsSinceEpoch.
ColladaData
ColladaLoader
Color
ColorKeyframeTrack
A Track of keyframe values that represent color.
ColorManagement
Composite
CompressedArrayTexture
CompressedTexture
Creates an texture 2D array based on data in compressed form, for example from a DDS file.
CompressedTextureLoader
Class for loading a texture. This uses the ImageLoader internally for loading files.
ConeGeometry
A class for generating cone geometries.
Console
ConvexGeometry
ConvexHull
CubeCamera
Creates 6 cameras that render to a page:WebGLCubeRenderTarget.
CubeRenderTarget
CubeTexture
Creates a cube texture made up of six images.
CubeTextureLoader
CubeTextureLoader can be used to load cube maps. The loader returns an instance of CubeTexture and expects the cube map to be defined as six separate images representing the sides of a cube. Other cube map definitions like vertical and horizontal cross, column and row layouts are not supported.
CubicBezierCurve
Create a smooth 2d cubic bezier curve, defined by a start point, endpoint and two control points.
CubicBezierCurve3
Create a smooth 3d cubic bezier curve, defined by a start point, endpoint and two control points.
CubicInterpolant
Fast and simple cubic spline interpolant.
CubicPoly
Curve
Extensible curve object.
CurvePath
An abstract base class extending Curve. A CurvePath is simply an array of connected curves, but retains the api of a curve.
CylinderGeometry
A class for generating cylinder geometries.
Data3DTexture
Creates a three-dimensional texture from raw data, with parameters to divide it into width, height, and depth.
DataArrayTexture
Creates an array of textures directly from raw data, width and height and depth.
DataTexture
Creates a texture directly from raw data, width and height.
DataTextureLoader
Abstract Base class to load generic binary textures formats (rgbe, hdr, ...)
DDSInfo
DDSLoader
DecalGeometry
DecalGeometry can be used to create a decal mesh that serves different kinds of purposes e.g. adding unique details to models, performing dynamic visual environmental changes or covering seams.
DecalVertex
DecoratedTorusKnot4a
DecoratedTorusKnot4b
DecoratedTorusKnot5a
DecoratedTorusKnot5c
DepthTexture
This class can be used to automatically save the depth information of a rendering into a texture.
DeviceOrientationControls
DirectionalLight
A light that gets emitted in a specific direction. This light will behave as though it is infinitely far away and the rays produced from it are all parallel. The common use case for this is to simulate daylight; the sun is far enough away that its position can be considered to be infinite, and all light rays coming from it are parallel.
DirectionalLightShadow
This is used internally by DirectionalLights for calculating shadows.
DiscreteInterpolant
Interpolant that evaluates to the sample value at the position preceeding the parameter.
DodecahedronGeometry
A class for generating a dodecahedron geometries.
DragControls
This class can be used to provide a drag'n'drop interaction.
Easing
The Ease class provides a collection of easing functions for use with tween.js.
EdgesGeometry
This can be used as a helper object to view the edges of a geometry.
EllipseCurve
Creates a 2d curve in the shape of an ellipse. Setting the xRadius equal to the yRadius will result in a circle.
Euler
A class representing Euler Angles.
Event
EventTouch
ExtrudeGeometry
Creates extruded geometry from a path shape.
ExtrudeGeometryOptions
Face
Face2
FBXLoader
Loader loads FBX file and generates Group representing FBX scene. Requires FBX file to be >= 7.0 and in ASCII or >= 6400 in Binary format Versions lower than this may load but will probably have errors
FigureEightPolynomialKnot
FileLoader
A low level class for loading resources with Fetch, used internally by most loaders. It can also be used directly to load any file type that does not have a loader.
FirstPersonControls
This class is an alternative implementation of FlyControls.
Float16BufferAttribute
Float32BufferAttribute
Float64BufferAttribute
FlutterTexture
Creates a texture from a canvas element.
FlyControls
FlyControls enables a navigation similar to fly modes in DCC tools like Blender. You can arbitrarily transform the camera in 3D space without any limitations (e.g. focus on a specific target).
FlyMoveState
Fog
This class contains the parameters that define linear fog, i.e., that grows linearly denser with the distance.
FogBase
FogExp2
This class contains the parameters that define exponential squared fog, which gives a clear view near the camera and a faster than exponentially densening fog farther from the camera.
Font
FontLoader
Class for loading a font in JSON format. Returns a font, which is an array of Shapes representing the font. This uses the FileLoader internally for loading files.
FramebufferTexture
This class can only be used in combination with WebGLRenderer.copyFramebufferToTexture. final pixelRatio = devicePixelRatio; final textureSize = 128 * pixelRatio;
FrenetFrames
Frustum
GCodeLoader
GCodeLoader is used to load gcode files usually used for 3D printing or CNC applications.
GLBufferAttribute
This buffer attribute class does not construct a VBO. Instead, it uses whatever VBO is passed in constructor and can later be altered via the buffer property.
GLTFData
GLTFLoader
glTF (GL Transmission Format) is an open format specification for efficient delivery and loading of 3D content. Assets may be provided either in JSON (.gltf) or binary (.glb) format. External files store textures (.jpg, .png) and additional binary data (.bin). A glTF asset may deliver one or more scenes, including meshes, materials, textures, skins, skeletons, morph targets, animations, lights, and/or cameras.
GrannyKnot
Group
This is almost identical to an Object3D. Its purpose is to make working with animatins of objects syntactically clearer.
GroupMaterial
GroupTexture
HalfEdge
HeartCurve
HelixCurve
HemisphereLight
A light source positioned directly above the scene, with color fading from the sky color to the ground color.
HemisphereLightProbe
HexTilingMaterial
HexTilingParams
Copyright (c) 2023-2024 Casey Primozic and others
IcosahedronGeometry
A class for generating an icosahedron geometry.
ImageDataInfo
ImageElement
ImageLoader
A loader for loading an Image. This is used internally by the CubeTextureLoader, ObjectLoader and TextureLoader.
InstancedBufferAttribute
An instanced version of BufferAttribute.
InstancedBufferGeometry
An instanced version of BufferGeometry.
InstancedInterleavedBuffer
An instanced version of InterleavedBuffer.
InstancedMesh
A special version of Mesh with instanced rendering support. Use name if you have to render a large number of objects with the same geometry and material but with different world transformations. The usage of name will help you to reduce the number of draw calls and thus improve the overall rendering performance in your application.
Int16BufferAttribute
Int32BufferAttribute
Int8BufferAttribute
InterleavedBuffer
Interleaved means that multiple attributes, possibly of different types, (e.g., position, normal, uv, color) are packed into a single array buffer.
InterleavedBufferAttribute
Interpolant
Abstract base class of interpolants over parametric samples.
Interpolation
Intersection
Joystick
KeyframeTrack
A KeyframeTrack is a timed sequence of keyframes, which are composed of lists of times and related values, and which are used to animate a specific property of an object.
Keys
KhronosTextureContainer
KinematicsData
KnotCurve
KTXLoader
for description see https://www.khronos.org/opengles/sdk/tools/KTX/ for file layout see https://www.khronos.org/opengles/sdk/tools/KTX/file_format_spec/
LatheGeometry
Creates meshes with axial symmetry like vases. The lathe rotates around the Y axis.
Layers
A Layers object assigns an Object3D to 1 or more of 32 layers numbered 0 to 31 - internally the layers are stored as a bit mask, and by default all Object3Ds are a member of layer 0.
Light
Abstract base class for lights - all other light types inherit the properties and methods described here.
LightProbe
Light probes are an alternative way of adding light to a 3D scene. Unlike classical light sources (e.g. directional, point or spot lights), light probes do not emit light. Instead they store information about light passing through 3D space. During rendering, the light that hits a 3D object is approximated by using the data from the light probe.
LightShadow
Serves as a base class for the other shadow classes.
Line
A continuous line.
Line3
A geometric line segment represented by a start and end point.
LinearInterpolant
final interpolant = LinearInterpolant( [0,0], [0,0], 1, [0] ); interpolant.evaluate( 0.5 );
LineBasicMaterial
A material for drawing wireframe-style geometries.
LineCurve
A curve representing a 2d line segment.
LineCurve3
A curve representing a 3d line segment.
LineDashedMaterial
A material for drawing wireframe-style geometries with dashed lines.
LineLoop
A continuous line that connects back to the start.
LineSegments
A series of lines drawn between pairs of vertices.
Loader
Base class for implementing loaders
LoaderUtils
LoadingManager
Handles and keeps track of loaded and pending data. A default global instance of this class is created and used by loaders if not supplied manually - see DefaultLoadingManager.
LOD
Level of Detail - show meshes with more or less geometry based on distance from the camera.
LUTCubeLoader
A 3D LUT loader that supports the .cube file format.
LUTCubeLoaderData
MapControls
Material
Abstract base class for materials.
MaterialCreator
Create a MTLLoader.MaterialCreator @param baseUrl - Url relative to which textures are loaded @param options - Set of options on how to construct the materials side: Which side to apply the material FrontSide (default), THREE.BackSide, THREE.DoubleSide wrap: What type of wrapping to apply for textures RepeatWrapping (default), THREE.ClampToEdgeWrapping, THREE.MirroredRepeatWrapping normalizeRGB: RGBs need to be normalized to 0-1 from 0-255 Default: false, assumed to be already normalized ignoreZeroRGBs: Ignore values of RGBs (Ka,Kd,Ks) that are all 0's Default: false @constructor
MathUtils
Matrix2
Represents a 2x2 matrix.
Matrix3
A class representing a 3x3 matrix.
Matrix4
MD2Character
MD2LoadData
MD2Loader
MD2LoaderData
Mesh
Class representing triangular polygon mesh based objects. Also serves as a base for other classes such as SkinnedMesh.
MeshBasicMaterial
A material for drawing geometries in a simple shaded (flat or wireframe) way.
MeshDepthMaterial
A material for drawing geometry by depth. Depth is based off of the camera near and far plane. White is nearest, black is farthest.
MeshDistanceMaterial
MeshDistanceMaterial is internally used for implementing shadow mapping with PointLights.
MeshGouraudMaterial
MeshLambertMaterial
A material for non-shiny surfaces, without specular highlights.
MeshMatcapMaterial
MeshMatcapMaterial is defined by a MatCap (or Lit Sphere) texture, which encodes the material color and shading.
MeshNormalMaterial
A material that maps the normal vectors to RGB colors.
MeshPhongMaterial
A material for shiny surfaces with specular highlights.
MeshPhysicalMaterial
An extension of the MeshStandardMaterial, providing more advanced physically-based rendering properties:
MeshStandardMaterial
A standard physically based material, using Metallic-Roughness workflow.
MeshToonMaterial
A material implementing toon shading.
MorphAnimMesh
MorphBuffers
MorphColor
MorphNormals
MorphTarget
Mouse
MTLLoader
The Material Template Library format (MTL) or .MTL File Format is a companion file format to .OBJ that describes surface shading (material) properties of objects within one or more .OBJ files.
MultiDrawRenderList
NumberKeyframeTrack
A Track of numeric keyframe values.
NURBSCurve
  • NURBS curve object
  • Derives from Curve, overriding getPoint and getTangent.
  • Implementation is based on (x, y [, z=0 , w=1]) control points with w=weight.
  • NURBSSurface
    NURBS surface object
    NURBSutils
    Object3D
    This is the base class for most objects in three.js and provides a set of properties and methods for manipulating objects in 3D space.
    Object3dMeta
    OBJLoader
    The OBJ file format is a simple data-format that represents 3D geometry in a human readable format as the position of each vertex, the UV position of each texture coordinate vertex, vertex normals, and the faces that make each polygon defined as a list of vertices, and texture vertices.
    OctahedronGeometry
    A class for generating an octahedron geometry.
    OpenGLTexture
    OrbitControls
    Orbit controls allow the camera to orbit around a target.
    OrbitState
    OrthographicCamera
    Camera that uses orthographic projection.
    Parameters
    ParametricGeometries
    Experimenting of primitive geometry creation using Surface Parametric equations
    ParametricGeometry
    Parametric Surfaces Geometry based on the brilliant article by prideout
    ParametricPlaneGeometry
    ParametricSphereGeometry
    ParametricTorusKnotCurve
    ParametricTorusKnotGeometry
    ParametricTubeGeometry
    ParserState
    ParseStateMaterial
    ParseStateObject
    Path
    A 2D path representation. The class provides methods for creating paths and contours of 2D shapes similar to the 2D Canvas API.
    PathInterpolations
    PathInterpolations contains spline and Bézier functions internally used by concrete curve classes.
    PCDHeader
    PCDLoader
    A loader for the Point Cloud Data (PCD) format.
    Peripherals
    PeripheralsState
    PerspectiveCamera
    Camera that uses perspective projection.
    Plane
    PlaneGeometry
    A class for generating plane geometries.
    PLYLoader
    Description: A THREE loader for PLY ASCII files (known as the Polygon File Format or the Stanford Triangle Format).
    PMREMGenerator
    PMREMGeneratorOptions
    PointerLockControls
    The implementation of this class is based on the Pointer Lock API. PointerLockControls is a perfect choice for first person 3D games.
    PointLight
    A light that gets emitted from a single point in all directions. A common use case for this is to replicate the light emitted from a bare lightbulb.
    PointLightShadow
    This is used internally by PointLights for calculating shadows.
    Points
    A class for displaying points. The points are rendered by the WebGLRenderer using gl.POINTS.
    PointsMaterial
    The default material used by Points.
    PolyhedronGeometry
    A polyhedron is a solid in three dimensions with flat faces. This class will take an array of vertices, project them onto a sphere, and then divide them up to the desired level of detail. This class is used by DodecahedronGeometry, IcosahedronGeometry, OctahedronGeometry, and TetrahedronGeometry to generate their respective geometries.
    Pool
    PositionalAudio
    PositionalAudioHelper
    ProjectedMaterial
    ProjectedMaterialUtils
    PropertyBinding
    PropertyMixer
    Buffered scene graph property that allows weighted accumulation; used internally.
    QuadraticBezierCurve
    Create a smooth 2d quadratic bezier curvehttp://en.wikipedia.org/wiki/B%C3%A9zier_curve#mediaviewer/File:B%C3%A9zier_2_big.gif), defined by a startpoint, endpoint and a single control point.
    QuadraticBezierCurve3
    Create a smooth 3d quadratic bezier curvehttp://en.wikipedia.org/wiki/B%C3%A9zier_curve#mediaviewer/File:B%C3%A9zier_2_big.gif), defined by a startpoint, endpoint and a single control point.
    Quaternion
    QuaternionKeyframeTrack
    A Track of quaternion keyframe values.
    QuaternionLinearInterpolant
    Spherical linear unit quaternion interpolant.
    Ranges
    RawShaderMaterial
    This class works just like ShaderMaterial, except that definitions of built-in uniforms and attributes are not automatically prepended to the GLSL shader code.
    Ray
    Raycaster
    This class is designed to assist with raycasting. Raycasting is used for mouse picking (working out what objects in the 3d space the mouse is over) amongst other things.
    RectAreaLight
    RectAreaLight emits light uniformly across the face a rectangular plane. This light type can be used to simulate light sources such as bright windows or strip lighting.
    Renderer
    RenderTarget
    RenderTargetOptions
    ReservedRange
    RGBELoader
    RingGeometry
    A class for generating a two-dimensional ring geometry.
    Scene
    Scenes allow you to set up what and where is to be rendered by three.js.
    Sequence
    Settings
    ShaderMaterial
    A material rendered with custom shaders. A shader is a small program written in GLSL that runs on the GPU. You may want to use a custom shader if you need to:
    ShadowMap
    ShadowMaterial
    This material can receive shadows, but otherwise is completely transparent.
    Shape
    Defines an arbitrary 2d shape plane using paths with optional holes. It can be used with ExtrudeGeometry, ShapeGeometry, to get points, or to get triangulated faces.
    ShapeGeometry
    Creates an one-sided polygonal geometry from one or more path shapes.
    ShapePath
    This class is used to convert a series of shapes to an array of Paths, for example an SVG shape to a path.
    ShapeUtils
    A class containing utility functions for shapes.
    Skeleton
    Use an array of bones to create a skeleton that can be used by a SkinnedMesh.
    SkinnedMesh
    A mesh that has a Skeleton with bones that can then be used to animate the vertices of the geometry.
    Source
    Represents the data source of a texture.
    SphereGeometry
    A class for generating sphere geometries.
    SphericalHarmonics3
    Primary reference: https://graphics.stanford.edu/papers/envmap/envmap.pdf
    SplineCurve
    Create a smooth 2d spline curve from a series of points. Internally this uses page:Interpolations.CatmullRom to create the curve.
    SpotLight
    This light gets emitted from a single point in one direction, along a cone that increases in size the further from the light it gets.
    SpotLightShadow
    This is used internally by SpotLights for calculating shadows.
    Sprite
    A sprite is a plane that always faces towards the camera, generally with a partially transparent texture applied.
    SpriteAnimation
    SpriteAnimator
    SpriteMaterial
    A material for a use with a Sprite.
    SpriteTexture
    State
    StereoCamera
    Dual page:PerspectiveCamera PerspectiveCameras used for effects such as 3D Anaglyph or Parallax Barrier.
    STLLoader
    Description: A THREE loader for STL ASCII files, as created by Solidworks and other CAD programs.
    StringKeyframeTrack
    A Track that interpolates Strings
    TetrahedronGeometry
    A class for generating a tetrahedron geometries.
    TextGeometry
    A class for generating text as a single geometry. It is constructed by providing a string of text, and a set of parameters consisting of a loaded font and settings for the geometry's parent ExtrudeGeometry. See the FontLoader page for additional details.
    TextGeometryOptions
    Texture
    Create a texture to apply to a surface or as a reflection or refraction map.
    TextureLoader
    Class for loading a texture. This uses the ImageLoader internally for loading files.
    TextureLoaderData
    TextureRangeInfo
    TextureUtils
    TGALoader
    ThirdPersonControls
    ThreeFile
    ThreeJS
    threeJs utility class. If you want to learn how to connect cannon.js with js, please look at the examples/threejs_* instead.
    TorusGeometry
    A class for generating torus geometries.
    TorusKnot
    TorusKnotGeometry
    Creates a torus knot, the particular shape of which is defined by a pair of coprime integers, p and q. If p and q are not coprime, the result will be a torus link.
    Touch
    TrackballControls
    TrackballControls is similar to OrbitControls. However, it does not maintain a constant camera up vector. That means if the camera orbits over the “north” and “south” poles, it does not flip to stay "right side up".
    TrefoilKnot
    TrefoilPolynomialKnot
    Triangle
    TTFFont
    TTFLoader
    Requires opentype.js to be included in the project. Loads TTF files and converts them into typeface JSON that can be used directly to create THREE.Font objects.
    TubeGeometry
    Creates a tube that extrudes along a 3d curve.
    Tween
    TweenGroup
    TypeByteLength
    TYPRFont
    TYPRLoader
    Requires opentype.js to be included in the project. Loads TTF files and converts them into typeface JSON that can be used directly to create Font objects.
    Uint16BufferAttribute
    Uint32BufferAttribute
    Uint8BufferAttribute
    Uint8ClampedBufferAttribute
    Uniform
    Uniforms are global GLSL variables. They are passed to shader programs.
    UniformsGroup
    UniformsUtils
    USDAParser
    USDZLoader
    Utils
    Vector
    Vector2
    Vector3
    Vector4
    VectorKeyframeTrack
    A Track of vectored keyframe values.
    VertexList
    VertexNode
    VideoTexture
    VideoTextureOptions
    VivianiCurve
    VOXData3DTexture
    VOXLoader
    VOXMesh
    WeakMap<K, V>
    A WeakMap lets you garbage-collect its keys. Please note: The key can be garbage-collected, not the value.
    WebPointerEvent
    WireframeGeometry
    This can be used as a helper object to view a BufferGeometry as a wireframe.
    WorldUVGenerator
    XRManager
    XYZLoader

    Mixins

    EventDispatcher
    JavaScript events for custom objects.

    Constants

    ACESFilmicToneMapping → const int
    AddEquation → const int
    AdditiveAnimationBlendMode → const int
    AdditiveBlending → const int
    AddOperation → const int
    AgXToneMapping → const int
    AlphaFormat → const int
    AlwaysCompare → const int
    AlwaysDepth → const int
    AlwaysStencilFunc → const int
    AttachedBindMode → const String
    backgroundCubeFrag → const String
    backgroundCubeVert → const String
    backgroundFrag → const String
    backgroundVert → const String
    BackSide → const int
    BasicDepthPacking → const int
    BasicShadowMap → const int
    ByteType → const int
    CineonToneMapping → const int
    ClampToEdgeWrapping → const int
    ConstantAlphaFactor → const int
    ConstantColorFactor → const int
    cubeFrag → const String
    CubeReflectionMapping → const int
    CubeRefractionMapping → const int
    CubeUVReflectionMapping → const int
    cubeVert → const String
    CullFaceBack → const int
    CullFaceFront → const int
    CullFaceFrontBack → const int
    CullFaceNone → const int
    CustomBlending → const int
    CustomToneMapping → const int
    DecrementStencilOp → const int
    DecrementWrapStencilOp → const int
    DepthFormat → const int
    depthFrag → const String
    DepthStencilFormat → const int
    depthVert → const String
    DetachedBindMode → const String
    DisplayP3ColorSpace → const String
    distanceRgbaVert → const String
    distanceRgbeFrag → const String
    DoubleSide → const int
    DstAlphaFactor → const int
    DstColorFactor → const int
    DynamicCopyUsage → const int
    DynamicDrawUsage → const int
    DynamicReadUsage → const int
    EqualCompare → const int
    EqualDepth → const int
    EqualStencilFunc → const int
    EquirectangularReflectionMapping → const int
    EquirectangularRefractionMapping → const int
    equirectFrag → const String
    equirectVert → const String
    FlatShading → const bool
    FloatType → const int
    FrontSide → const int
    GammaEncoding → const int
    GLSL1 → const String
    GLSL3 → const String
    GreaterCompare → const int
    GreaterDepth → const int
    GreaterEqualCompare → const int
    GreaterEqualDepth → const int
    GreaterEqualStencilFunc → const int
    GreaterStencilFunc → const int
    HalfFloatType → const int
    IncrementStencilOp → const int
    IncrementWrapStencilOp → const int
    InterpolateDiscrete → const int
    InterpolateLinear → const int
    InterpolateSmooth → const int
    IntType → const int
    InvertStencilOp → const int
    KeepStencilOp → const int
    LessCompare → const int
    LessDepth → const int
    LessEqualCompare → const int
    LessEqualDepth → const int
    LessEqualStencilFunc → const int
    LessStencilFunc → const int
    LinearDisplayP3ColorSpace → const String
    LinearEncoding → const int
    LinearFilter → const int
    LinearMipMapLinearFilter → const int
    LinearMipmapLinearFilter → const int
    LinearMipMapNearestFilter → const int
    LinearMipmapNearestFilter → const int
    LinearSRGBColorSpace → const String
    LinearToneMapping → const int
    LinearTransfer → const String
    linedashedFrag → const String
    linedashedVert → const String
    LogLuvEncoding → const int
    LoopOnce → const int
    LoopPingPong → const int
    LoopRepeat → const int
    LuminanceAlphaFormat → const int
    LuminanceFormat → const int
    MAX_SAFE_INTEGER → const int
    MaxEquation → const int
    meshbasicFrag → const String
    meshbasicVert → const String
    meshlambertFrag → const String
    meshlambertVert → const String
    meshmatcapFrag → const String
    meshmatcapVert → const String
    meshnormalFrag → const String
    meshnormalVert → const String
    meshphongFrag → const String
    meshphongVert → const String
    meshphysicalFrag → const String
    meshphysicalVert → const String
    meshtoonFrag → const String
    meshtoonVert → const String
    MinEquation → const int
    MirroredRepeatWrapping → const int
    MixOperation → const int
    MultiplyBlending → const int
    MultiplyOperation → const int
    NearestFilter → const int
    NearestMipMapLinearFilter → const int
    NearestMipmapLinearFilter → const int
    NearestMipMapNearestFilter → const int
    NearestMipmapNearestFilter → const int
    NeutralToneMapping → const int
    NeverCompare → const int
    NeverDepth → const int
    NeverStencilFunc → const int
    NoBlending → const int
    NoColorSpace → const String
    NormalAnimationBlendMode → const int
    NormalBlending → const int
    NotEqualCompare → const int
    NotEqualDepth → const int
    NotEqualStencilFunc → const int
    NoToneMapping → const int
    ObjectSpaceNormalMap → const int
    OneFactor → const int
    OneMinusConstantAlphaFactor → const int
    OneMinusConstantColorFactor → const int
    OneMinusDstAlphaFactor → const int
    OneMinusDstColorFactor → const int
    OneMinusSrcAlphaFactor → const int
    OneMinusSrcColorFactor → const int
    P3Primaries → const String
    PCFShadowMap → const int
    PCFSoftShadowMap → const int
    pointsFrag → const String
    pointsVert → const String
    Rec709Primaries → const String
    RED_GREEN_RGTC2_Format → const int
    RED_RGTC1_Format → const int
    RedFormat → const int
    RedIntegerFormat → const int
    ReinhardToneMapping → const int
    RepeatWrapping → const int
    ReplaceStencilOp → const int
    ReverseSubtractEquation → const int
    REVISION → const String
    RGB_BPTC_SIGNED_Format → const int
    RGB_BPTC_UNSIGNED_Format → const int
    RGB_ETC1_Format → const int
    RGB_ETC2_Format → const int
    RGB_PVRTC_2BPPV1_Format → const int
    RGB_PVRTC_4BPPV1_Format → const int
    RGB_S3TC_DXT1_Format → const int
    RGBA_ASTC_10x10_Format → const int
    RGBA_ASTC_10x5_Format → const int
    RGBA_ASTC_10x6_Format → const int
    RGBA_ASTC_10x8_Format → const int
    RGBA_ASTC_12x10_Format → const int
    RGBA_ASTC_12x12_Format → const int
    RGBA_ASTC_4x4_Format → const int
    RGBA_ASTC_5x4_Format → const int
    RGBA_ASTC_5x5_Format → const int
    RGBA_ASTC_6x5_Format → const int
    RGBA_ASTC_6x6_Format → const int
    RGBA_ASTC_8x5_Format → const int
    RGBA_ASTC_8x6_Format → const int
    RGBA_ASTC_8x8_Format → const int
    RGBA_BPTC_Format → const int
    RGBA_ETC2_EAC_Format → const int
    RGBA_PVRTC_2BPPV1_Format → const int
    RGBA_PVRTC_4BPPV1_Format → const int
    RGBA_S3TC_DXT1_Format → const int
    RGBA_S3TC_DXT3_Format → const int
    RGBA_S3TC_DXT5_Format → const int
    RGBADepthPacking → const int
    RGBAFormat → const int
    RGBAIntegerFormat → const int
    RGBDEncoding → const int
    RGBEEncoding → const int
    RGBEFormat → const int
    RGBFormat → const int
    RGBIntegerFormat → const int
    RGBM16Encoding → const int
    RGBM7Encoding → const int
    RGFormat → const int
    RGIntegerFormat → const int
    shadowFrag → const String
    shadowVert → const String
    ShortType → const int
    SIGNED_RED_GREEN_RGTC2_Format → const int
    SIGNED_RED_RGTC1_Format → const int
    SmoothShading → const int
    spriteFrag → const String
    spriteVert → const String
    SrcAlphaFactor → const int
    SrcAlphaSaturateFactor → const int
    SrcColorFactor → const int
    SRGBAFormat → const int
    SRGBColorSpace → const String
    sRGBEncoding → const int
    SRGBFormat → const int
    SRGBTransfer → const String
    StaticCopyUsage → const int
    StaticDrawUsage → const int
    StaticReadUsage → const int
    StreamCopyUsage → const int
    StreamDrawUsage → const int
    StreamReadUsage → const int
    SubtractEquation → const int
    SubtractiveBlending → const int
    TangentSpaceNormalMap → const int
    TriangleFanDrawMode → const int
    TrianglesDrawMode → const int
    TriangleStripDrawMode → const int
    UnsignedByteType → const int
    UnsignedInt248Type → const int
    UnsignedInt5999Type → const int
    UnsignedIntType → const int
    UnsignedShort4444Type → const int
    UnsignedShort5551Type → const int
    UnsignedShort565Type → const int
    UnsignedShortType → const int
    UVMapping → const int
    vsmFrag → const String
    VSMShadowMap → const int
    vsmVert → const String
    WebGLCoordinateSystem → const int
    WebGPUCoordinateSystem → const int
    WrapAroundEnding → const int
    ZeroCurvatureEnding → const int
    ZeroFactor → const int
    ZeroSlopeEnding → const int
    ZeroStencilOp → const int

    Properties

    angleLightsFragmentBegin String
    getter/setter pair
    angleLightsParsBegin String
    getter/setter pair
    angleShaderChunk Map<String, String>
    getter/setter pair
    connections Map?
    getter/setter pair
    console Console
    getter/setter pair
    dataArray List
    final
    defaultLoadingManager LoadingManager
    final
    extraLodSigma List<double>
    final
    fn Map<ColorSpace, dynamic>
    final
    horizontalBlurShader Map<String, dynamic>
    Two pass Gaussian blur filter (horizontal and vertical blur shaders)
    getter/setter pair
    ID_ATTR_NAME String
    final
    ldp32lsrgb Matrix3
    final
    lightsFragmentBegin String
    getter/setter pair
    lightsParsBegin String
    getter/setter pair
    loading Map<String, dynamic>
    getter/setter pair
    lodMin int
    This class generates a Prefiltered, Mipmapped Radiance Environment Map (PMREM) from a cubeMap environment texture. This allows different levels of blur to be quickly accessed based on material roughness. It is packed into a special CubeUV format that allows us to perform custom interpolation so that we can support nonlinear formats such as RGBE. Unlike a traditional mipmap chain, it only goes down to the lodMin level (above), and then creates extra even more filtered 'mips' at the same lodMin resolution, associated with higher roughness levels. In this way we maintain resolution to smoothly interpolate diffuse lighting while limiting sampling computation.
    getter/setter pair
    lsrgb2ldp3 Matrix3
    final
    m1 Matrix4
    final
    materialId int
    getter/setter pair
    px CubicPoly
    final
    py CubicPoly
    final
    pz CubicPoly
    final
    sceneGraph AnimationObject?
    getter/setter pair
    shaderChunk Map<String, String>
    getter/setter pair
    shaderLib Map<String, dynamic>
    getter/setter pair
    shaderLibStandard Map<String, dynamic>
    getter/setter pair
    tempEuler Euler
    final
    tempVec Vector3
    final
    textureId int
    getter/setter pair
    tmp Vector3
    final
    uniformsLib Map<String, dynamic>
    getter/setter pair
    verticalBlurShader Map<String, dynamic>
    Two pass Gaussian blur filter (horizontal and vertical blur shaders)
    getter/setter pair

    Functions

    ascIdSort(dynamic a, dynamic b) int
    checkIntersection(Object3D object, Material? material, Raycaster raycaster, Ray ray, Vector3 pA, Vector3 pB, Vector3 pC, Vector3 point) Intersection?
    cloneUniforms(Map<String, dynamic> src) Map<String, dynamic>
    cloneUniformsGroups<T>(dynamic src) List
    copyAttributeData(dynamic src, dynamic target, [int targetOffset = 0]) → void
    createObjectURL(dynamic blob) → dynamic
    curves(String type, dynamic a, dynamic b, dynamic c, dynamic d, dynamic e, dynamic f) Curve?
    getTrackTypeForValueTypeName(String typeName) String
    getUnlitUniformColorSpace(Renderer renderer) String
    isUniqueEdge(Vector3 start, Vector3 end, dynamic edges) bool
    mergeUniforms(dynamic uniforms) Map<String, dynamic>
    now() int
    parseKeyframeTrack(Map<String, dynamic> json) KeyframeTrack
    scaleTo(double x, double y, double t) double
    serializeImage(dynamic image) Map<String, dynamic>
    sortOpaque(Pool a, Pool b) int
    sortTransparent(Pool a, Pool b) int
    testPoint(Vector3 point, int index, double localThresholdSq, Matrix4 matrixWorld, Raycaster raycaster, List<Intersection> intersects, Object3D object) → void
    toJSON2(dynamic shapes, Map<String, dynamic>? options, dynamic data) Map<String, dynamic>
    transformVertex(Vector3 vertexPosition, Vector3 mvPosition, Vector2 center, Vector scale, double? sin, double? cos) → void

    Typedefs

    OnRender = void Function({Camera? camera, BufferGeometry? geometry, Map<String, dynamic>? group, Material? material, Object3D? mesh, RenderTarget? renderTarget, Renderer? renderer, Scene? scene})